summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
authorNikos Mavrogiannopoulos <nmav@gnutls.org>2002-08-18 17:45:45 +0000
committerNikos Mavrogiannopoulos <nmav@gnutls.org>2002-08-18 17:45:45 +0000
commite4a2afc3614786d3a584d6dbbdb17ac57ae592cf (patch)
treed9e4758439ed52a570830e6a1c22a2b3e4b0f67b
parentec57ed29c83d25bea9833944e91de67bb1d6ab11 (diff)
downloadgnutls-e4a2afc3614786d3a584d6dbbdb17ac57ae592cf.tar.gz
gnutls_handshake_check_direction() renamed to gnutls_handshake_get_direction().
-rw-r--r--NEWS2
-rw-r--r--lib/gnutls.h.in.in2
-rw-r--r--lib/gnutls_handshake.c4
3 files changed, 4 insertions, 4 deletions
diff --git a/NEWS b/NEWS
index 6082d9755e..39108de441 100644
--- a/NEWS
+++ b/NEWS
@@ -3,7 +3,7 @@ Version 0.5.2
to export only servers. This must be enabled using the
gnutls_handshake_set_exportable_detection() function.
- Updated openssl compatibility layer.
-- Added gnutls_handshake_check_direction() function which returns
+- Added gnutls_handshake_get_direction() function which returns
the state of the handshake when interrupted.
Version 0.5.1 (17/07/2002)
diff --git a/lib/gnutls.h.in.in b/lib/gnutls.h.in.in
index 93e203aabf..9b9ede21c4 100644
--- a/lib/gnutls.h.in.in
+++ b/lib/gnutls.h.in.in
@@ -120,7 +120,7 @@ int gnutls_bye( GNUTLS_STATE state, GNUTLS_CloseRequest how);
int gnutls_handshake( GNUTLS_STATE state);
int gnutls_rehandshake( GNUTLS_STATE state);
-int gnutls_handshake_check_direction(GNUTLS_STATE state);
+int gnutls_handshake_get_direction(GNUTLS_STATE state);
GNUTLS_AlertDescription gnutls_alert_get( GNUTLS_STATE state);
int gnutls_alert_send( GNUTLS_STATE, GNUTLS_AlertLevel, GNUTLS_AlertDescription);
diff --git a/lib/gnutls_handshake.c b/lib/gnutls_handshake.c
index 6dd01ca71e..d870cf7ec6 100644
--- a/lib/gnutls_handshake.c
+++ b/lib/gnutls_handshake.c
@@ -1789,7 +1789,7 @@ int gnutls_rehandshake(GNUTLS_STATE state)
}
/**
* gnutls_handshake_check_direction - This function will return the state of the handshake protocol
* @state: is a a &GNUTLS_STATE structure.
*
* This function provides information about the handshake procedure, and
@@ -1800,7 +1800,7 @@ int gnutls_rehandshake(GNUTLS_STATE state)
* 1 otherwise.
*
**/
-int gnutls_handshake_check_direction(GNUTLS_STATE state) {
+int gnutls_handshake_get_direction(GNUTLS_STATE state) {
return state->gnutls_internals.handshake_direction;
}
@@ -1789,7 +1789,7 @@ int gnutls_rehandshake(GNUTLS_STATE state)
}
/**
- * gnutls_handshake_check_direction - This function will return the state of the handshake protocol
+ * gnutls_handshake_get_direction - This function will return the state of the handshake protocol
* @state: is a a &GNUTLS_STATE structure.
*